@@ -877,8 +877,8 @@ class Askdata(SignUp):
             for condition in join_conditions:
                 left_conditions.append(condition["left_on"])
                 right_conditions.append(condition["right_on"])
-            left_conditions = self.__retrieve_og_columns(left_conditions, df)
-            right_conditions = self.__retrieve_og_columns(right_conditions, df_query)
+            #left_conditions = self.__retrieve_og_columns(left_conditions, df)
+            #right_conditions = self.__retrieve_og_columns(right_conditions, df_query)
             return df.merge(df_query, how, None, left_conditions, right_conditions)
 
         return df.merge(df_query, how, on, left_on, right_on)
@@ -1096,12 +1096,12 @@ class Askdata(SignUp):
 
         response = s.post(url=url, json=body, headers=self._headers)
         response.raise_for_status()
-        result = response.json()
+        result = response.json()["cards"]
         try:
             if(dataset_id!=''):
                 filtered_result = []
                 for r in result:
-                    if(r["attachment"]["body"]["cards"][0]["details"]["datasetId"]==dataset_id):
+                    if(r["attachment"]["body"][0]["details"]["datasetId"]==dataset_id):
                         filtered_result.append(r)
             else:
                 filtered_result = result
@@ -1113,19 +1113,19 @@ class Askdata(SignUp):
             elif self._env == 'prod':
                 app_url = url_list['BASE_URL_APP_PROD']
 
-            url_1 = app_url + "/" + workspace+"/"+filtered_result[0]["attachment"]["body"]["cards"][0]["details"]["datasetSlug"]
+            url_1 = app_url + "/" + workspace+"/"+filtered_result[0]["attachment"]["body"][0]["details"]["datasetSlug"]
             display(HTML('<p>{} from the dataset: {} / {} : (<a href="{}" target="_blank">{}</a>) <- Use this source</p>'.format(self.extract_fields(filtered_result[0]["attachment"]["body"][0]["details"]["columns"]), workspace, filtered_result[0]["attachment"]["body"][0]["details"]["datasetName"], url_1, url_1)))
             if(len(filtered_result[0]["attachment"]["body"])>1):
-                display(HTML("<p>Filtered by: {}</p>".format(filtered_result[0]["attachment"]["body"]["cards"][1]["details"]["text"])))
+                display(HTML("<p>Filtered by: {}</p>".format(filtered_result[0]["attachment"]["body"][1]["details"]["text"])))
             if(len(filtered_result)>1):
                 display(HTML("<p>{} Alternatives:</p>".format(len(filtered_result)-1)))
                 for r in filtered_result[1:]:
-                    url_i = app_url + "/" + workspace + "/" + r["attachment"]["body"]["cards"][0]["details"]["datasetSlug"]
+                    url_i = app_url + "/" + workspace + "/" + r["attachment"]["body"][0]["details"]["datasetSlug"]
                     display(HTML('<p>     {} from the dataset: {} / {} ((<a href="{}" target="_blank">{}</a>)) <- Use this source</p>'.format(self.extract_fields(r["attachment"]["body"][0]["details"]["columns"]), workspace, r["attachment"]["body"][0]["details"]["datasetName"], url_i, url_i)))
             if get_raw_data:
-                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"]["cards"][0]["details"]["rawData"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
+                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rawData"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
             else:
-                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"]["cards"][0]["details"]["rows"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
+                df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rows"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
             return df
         except Exception as e:
             logging.error("Query did not produce any result")
