@@ -57,23 +57,24 @@ class Dataset():
 
         self._agentId=agent_id
 
-        if(slug!=''):
-            self._get_info_dataset_by_slug(slug)
-
         if env == 'dev':
             self._base_url_dataset = url_list['BASE_URL_DATASET_DEV']
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_DEV']
-        if env == 'qa':
+        elif env == 'qa':
             self._base_url_dataset = url_list['BASE_URL_DATASET_QA']
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_QA']
-        if env == 'prod':
+        elif env == 'prod':
             self._base_url_dataset = url_list['BASE_URL_DATASET_PROD']
             self._base_url_askdata = url_list['BASE_URL_ASKDATA_PROD']
 
+        if (slug != ''):
+            self._get_info_dataset_by_slug(slug)
+
     def _get_info_dataset_by_slug(self, slug: str):
 
         list_datasets = self.list_datasets()
         dataset = list_datasets[list_datasets['slug'] == slug]
+        self._domain = dataset.iloc[0]['domain']
         self._dataset_type = dataset.iloc[0]['type']
         self._dataset_id = dataset.iloc[0]['id']
         self._dataset_code = dataset.iloc[0]['code']
@@ -681,7 +682,19 @@ class Dataset():
         else:
             raise Exception("dataset didn't instantiate with slug")
 
+    def set_synonym_transformers(self, column_code, synonym_transformers):
+        if(type(synonym_transformers)==str):
+            synonym_transformers_list = []
+            synonym_transformers_list.append(synonym_transformers)
+        else:
+            synonym_transformers_list = synonym_transformers
 
+        column_code_settings = self.__retrive_entity(entity_code=column_code, dataset_id=self._dataset_id,
+                                                     dataset_type=self._dataset_type)
+        column_code_settings['synonymTransformers'].extend(synonym_transformers_list)
+        self.__put_entity_dataset(entity_code=column_code_settings['code'], dataset_id=self._dataset_id,
+                                  settigs_entity=column_code_settings,
+                                  entity_type=column_code_settings['parameterType'], dataset_type=self._dataset_type)
 
     def set_synonym(self,column_code: str,synonyms: list, replace=False):
         """
@@ -705,6 +718,38 @@ class Dataset():
                                   settigs_entity=column_code_settings,
                                   entity_type=column_code_settings['parameterType'], dataset_type=self._dataset_type)
 
+    def add_synonym_to_value(self, column_code: str, row_code, synonyms: list):
+
+        value_object = self.__get_values_from_entity(column_code, row_code)
+        value_object["synonyms"].extend(synonyms)
+
+        url = self._base_url_askdata+"/smartmanager/data/"+self._domain+"/entity/"+column_code
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+
+        # put field into exist value
+        response = s.put(url=url, headers=self._headers, json=value_object)
+        response.raise_for_status()
+
+    def __get_values_from_entity(self, column_code, value_code):
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        dataset_url = self._base_url_askdata + '/smartmanager/data/'+self._domain+'/entity/'+column_code+'?filter=%257B%257D'
+        response = s.get(url=dataset_url, headers=self._headers)
+        response.raise_for_status()
+        data=response.json()["payload"]["data"]
+        #print(data)
+        for value in data:
+            if(value_code==value["code"]):
+                return value
 
     def get_synonym(self,column_code: str) -> list:
         """
