@@ -21,11 +21,13 @@ def ask_dataframe(dataframe: pd.DataFrame, query: str):
     human2sql_url = url_list['BASE_URL_HUMAN2SQL_DEV']
 
     human2sql_response = requests.post(human2sql_url, json=human2sql_request)
-    response_df = None
+    response_df = []
     if human2sql_response.ok:
         res = human2sql_response.json()
         if 'result' in res:
-            response_df = pd.DataFrame(res['result'])
+            all_dfs = res['result']
+            for df in all_dfs:
+                response_df.append(pd.DataFrame(df))
         if 'messages' in res and res['messages']:
             for mex in res['messages']:
                 print(mex)
