@@ -26,16 +26,16 @@ with open(yaml_path, 'r') as file:
 class Insight_Definition:
 
 
-    def __init__(self, env:str, token, agent_slug, defintion):
+    def __init__(self, env:str, token, agent_slug, definition):
 
-        self.definition_id = defintion["id"]
-        self.agent_id = defintion["agentId"]
+        self.definition_id = definition["id"]
+        self.agent_id = definition["agentId"]
         self.agent_slug = agent_slug
-        self.collection_id = defintion["collectionId"]
-        self.name = defintion["name"]
-        self.slug = defintion["slug"]
-        self.icon = defintion["icon"]
-        self.components: list = defintion["components"]
+        self.collection_id = definition["collectionId"]
+        self.name = definition["name"]
+        self.slug = definition["slug"]
+        self.icon = definition["icon"]
+        self.components: list = definition["components"]
         self._env = env
         self._token = token
 
@@ -1353,11 +1353,11 @@ class Insight_Definition:
                 r.raise_for_status()
 
                 definition = r.json()
-                insight_definition = Insight_Definition(self._env, self._token, definition)
+                insight_definition = Insight_Definition(self._env, self._token, self.agent_slug, definition)
                 insight_definition.delete()
             except Exception as e:
                 logging.info("{} card not found... creating new one".format(card_slug))
-                logging.info("{}".format(e.with_traceback()))
+                logging.info("{}".format(e.__str__()))
 
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/clone"
