@@ -48,6 +48,7 @@ class SQLOperator(Enum):
     IN = auto()
     NOT_IN = auto()
     SEARCH = auto()
+    TIMESPAN = auto()
     FOREACH = auto()
 
 
@@ -207,6 +208,7 @@ class From:
 @dataclass
 class Query:
     fields: List[Field]
+    pivot: Optional[List[Field]]
     id: Optional[str] = None
     datasets: Optional[List[From]] = None
     where: Optional[List[Union[Condition, CompositeCondition]]] = None
