@@ -12,7 +12,7 @@ if __name__ == '__main__':
     condition1 = Condition(field4, "FROM", direction="NEXT", steps="{{number.A}}", interval="{{timeDimension.B}}")
     condition2 = Condition(field1, "LOE", ["{{number.B}}"])
     condition3 = Condition(field2, "IN", ["{{entity.A}}"])
-    condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}"], vuntil=["{{timePeriodEnd.A}}"])
+    condition4 = Condition(field4, "RANGE", value=["{{timePeriodStart.A}}", "{{timePeriodEnd.A}}"])
     sorting1 = Sorting("{{measure.A}}", SQLSorting.DESC)
     component = ChartComponent(type='chart', queryId="0", chartType='LINE')
     query1 = Query(fields=[field1, field2, field3], datasets=[from1, from2, from3], where=[condition1, condition2, condition3, condition4],
